severity = 3
verbose  = 9
exclude  = Subroutines::ProhibitUnusedPrivateSubroutines ValuesAndExpressions::ProhibitVersionStrings RegularExpressions::RequireExtendedFormatting ValuesAndExpressions::ProhibitVersionStrings
include  = Variables::ProhibitPackageVars
